pub struct LinkedFile {
pub clobbered: bool,
pub sha256: Sha256Hash,
pub file_size: u64,
pub relative_path: PathBuf,
pub method: LinkMethod,
pub prefix_placeholder: Option<String>,
}Expand description
The successful result of calling link_file.
Fields
clobbered: boolTrue if an existing file already existed and linking overwrote the original file.
sha256: Sha256HashThe SHA256 hash of the resulting file.
file_size: u64The size of the final file in bytes.
relative_path: PathBufThe relative path of the file in the destination directory. This might be different from the relative path in the source directory for python noarch packages.
method: LinkMethodThe way the file was linked
prefix_placeholder: Option<String>The original prefix placeholder that was replaced