PythonInfo

Struct PythonInfo 

pub struct PythonInfo {
    pub platform: Platform,
    pub short_version: (u64, u64),
    pub path: PathBuf,
    pub site_packages_path: PathBuf,
    pub bin_dir: PathBuf,
}
Information required for linking no-arch python packages. The struct contains information about a specific Python version that is installed in an environment.

Fields

platform: Platform

The platform that the python package is installed for

short_version: (u64, u64)

The major and minor version

path: PathBuf

The relative path to the python executable

site_packages_path: PathBuf

The relative path to where site-packages are stored

bin_dir: PathBuf

Path to the binary directory

Implementations

Source

impl PythonInfo

pub fn from_python_record( record: &PackageRecord, platform: Platform, ) -> Result<Self, PythonInfoError>

Build an instance based on metadata of the package that represents the python interpreter.

pub fn from_version( version: &Version, site_packages_path: Option<&str>, platform: Platform, ) -> Result<Self, PythonInfoError>

Build an instance based on the version of the python package and the platform it is installed for.

pub fn path(&self) -> &Path

Returns the path to the python executable

pub fn shebang(&self, target_prefix: &str) -> String

Constructs a shebang that will run the rest of the script as Python.

pub fn get_python_noarch_target_path<'a>( &self, relative_path: &'a Path, ) -> Cow<'a, Path>

Returns the target location of a file in a noarch python package given its location in its package archive.

Returns true if this version of python differs so much that a relink is required for all noarch python packages.