pub struct PythonInfo {
pub platform: Platform,
pub short_version: (u64, u64),
pub path: PathBuf,
pub site_packages_path: PathBuf,
pub bin_dir: PathBuf,
}Expand description
Information required for linking no-arch python packages. The struct contains information about a specific Python version that is installed in an environment.
Fields
platform: PlatformThe platform that the python package is installed for
short_version: (u64, u64)The major and minor version
path: PathBufThe relative path to the python executable
site_packages_path: PathBufThe relative path to where site-packages are stored
bin_dir: PathBufPath to the binary directory
Implementations
Sourceimpl PythonInfo
impl PythonInfo
Sourcepub fn from_python_record(
record: &PackageRecord,
platform: Platform,
) -> Result<Self, PythonInfoError>
pub fn from_python_record( record: &PackageRecord, platform: Platform, ) -> Result<Self, PythonInfoError>
Build an instance based on metadata of the package that represents the python interpreter.
Sourcepub fn from_version(
version: &Version,
site_packages_path: Option<&str>,
platform: Platform,
) -> Result<Self, PythonInfoError>
pub fn from_version( version: &Version, site_packages_path: Option<&str>, platform: Platform, ) -> Result<Self, PythonInfoError>
Build an instance based on the version of the python package and the platform it is installed for.
Sourcepub fn shebang(&self, target_prefix: &str) -> String
pub fn shebang(&self, target_prefix: &str) -> String
Constructs a shebang that will run the rest of the script as Python.
Sourcepub fn get_python_noarch_target_path<'a>(
&self,
relative_path: &'a Path,
) -> Cow<'a, Path>
pub fn get_python_noarch_target_path<'a>( &self, relative_path: &'a Path, ) -> Cow<'a, Path>
Returns the target location of a file in a noarch python package given its location in its package archive.
Sourcepub fn is_relink_required(&self, previous: &PythonInfo) -> bool
pub fn is_relink_required(&self, previous: &PythonInfo) -> bool
Returns true if this version of python differs so much that a relink is required for all noarch python packages.